@@ -1,6 +1,7 @@
 import numpy as np
 import matplotlib.pyplot as plt
 import pandas as pd
+from matplotlib import cm
 
 def Trajectory (data, bodyPartTraj, bodyPartBox, cmapType = 'viridis', figureTitle = None, 
               hSize=6, wSize =8,fontsize=15, invertY = True, saveName=None, figformat =".eps"):
@@ -10,7 +11,7 @@ def Trajectory (data, bodyPartTraj, bodyPartBox, cmapType = 'viridis', figureTit
     Parameters
     ----------
     data : pandas DataFrame
-        The input.
+        The input tracking data.
     bodyPartTraj : str
         Body part you want to plot the tracking.
     bodyPartBox : str
@@ -32,7 +33,7 @@ def Trajectory (data, bodyPartTraj, bodyPartBox, cmapType = 'viridis', figureTit
         Determine the save name of the plot.        
     figformat : str, optional
         Determines the type of file that will be saved. Used as base the ".eps", 
-        which may be another supported by matplotlib..  
+        which may be another supported by matplotlib. 
 
     Returns
     -------
@@ -40,7 +41,6 @@ def Trajectory (data, bodyPartTraj, bodyPartBox, cmapType = 'viridis', figureTit
         The output of the function is the figure with the tracking plot of the 
         selected body part.
 
-
     See Also
     --------
     For more information and usage examples: https://github.com/pyratlib/pyrat
@@ -98,7 +98,7 @@ def Heatmap(data, bodyPart, cmapType = 'viridis', figureTitle = None, hSize=6, w
     Parameters
     ----------
     data : pandas DataFrame
-        The input.
+        The input tracking data.
     bodyPart : str
         Body part you want to plot the heatmap.
     cmapType : str, optional
@@ -122,14 +122,12 @@ def Heatmap(data, bodyPart, cmapType = 'viridis', figureTitle = None, hSize=6, w
         Determine the save name of the plot.        
     figformat : str, optional
         Determines the type of file that will be saved. Used as base the ".eps", 
-        which may be another supported by matplotlib..  
+        which may be another supported by matplotlib. 
 
     Returns
     -------
     out : plot
-        The output of the function is the figure with the tracking plot of the 
-        selected body part.
-
+        The output of the function is the figure with the heatpmat of trackin.
 
     See Also
     --------
@@ -145,8 +143,8 @@ def Heatmap(data, bodyPart, cmapType = 'viridis', figureTitle = None, hSize=6, w
     x = values[:,lista1.index(bodyPart+" - x")]
     y = values[:,lista1.index(bodyPart+" - y")]
 
+    plt.rcParams["font.family"] = "Arial"
     plt.figure(figsize=(wSize, hSize), dpi=80)
-
     plt.hist2d(x,y, bins = bins, vmax = vmax,cmap=plt.get_cmap(cmapType))
 
     cb = plt.colorbar()
@@ -162,4 +160,87 @@ def Heatmap(data, bodyPart, cmapType = 'viridis', figureTitle = None, hSize=6, w
 
     if saveName != None:
         plt.savefig(saveName+figformat)
-    plt.show()
\ No newline at end of file
+    plt.show()
+
+def ScaleConverter(dado, pixel_max,pixel_min,max_real, min_real=0):
+    """
+    It performs the pixel conversion to the determined real scale (meter, 
+    centimeter, millimeter...).
+
+    Parameters
+    ----------
+    data : pandas DataFrame
+        The input tracking data.
+    pixel_max : int
+        Pixel maximum value. 
+    pixel_min : int
+        Pixel minimum value.   
+    max_real : int
+        Box maxixum value (eg., box wall).
+    min_real : int
+        Box maxixum value, usually zero.
+
+    Returns
+    -------
+    out : int
+        Scale factor of your box.
+
+    See Also
+    --------
+    For more information and usage examples: https://github.com/pyratlib/pyrat
+
+    Notes
+    -----
+    This function was developed based on DLC outputs and is able to support 
+    matplotlib configurations."""    
+
+    return min_real + ((dado-pixel_min)/(pixel_max-pixel_min)) * (max_real-min_real)
+
+def MotionMetrics (data, bodyPart, filter=0,  fps=30):
+    """
+    Performs motion-related metrics such as velocity, acceleration, and distance.
+
+    Parameters
+    ----------
+    data : pandas DataFrame
+        The input tracking data.
+    bodyPart : str
+        Body part you want use as reference.
+    filter : int
+        Threshold to remove motion artifacts.   
+    fps : int
+        The recording frames per second.
+
+    Returns
+    -------
+    out : pandas DataFrame
+        All metrics in the df.
+
+    See Also
+    --------
+    For more information and usage examples: https://github.com/pyratlib/pyrat
+
+    Notes
+    -----
+    This function was developed based on DLC outputs and is able to support 
+    matplotlib configurations."""
+
+    values = (data.iloc[2:,1:].values).astype(np.float)
+    lista1 = (data.iloc[0][1:].values +" - " + data.iloc[1][1:].values).tolist()
+
+    dataX = values[:,lista1.index(bodyPart+" - x")]
+    dataY = values[:,lista1.index(bodyPart+" - y")]
+
+    dataX = scaleConverter(dataX,dataX.max(),dataX.min(), 60,0)
+    dataY = scaleConverter(dataY,dataY.max(),dataY.min(), 60,0)
+
+    time = np.arange(0,((1/fps)*len(dataX)), (1/fps))
+    df = pd.DataFrame(time, columns = ["Time"])
+    dist = np.hypot(np.diff(dataX, prepend=dataX[0]), np.diff(dataY, prepend=dataY[0]))
+    dist[dist>=filter] = 0
+    dist[0] = "nan"
+    df["Distance"] = dist
+    df['Speed'] = df['Distance']/(1/fps)
+    df['Acceleration'] =  df['Speed'].diff().abs()/(1/fps)
+
+    return df
\ No newline at end of file
